@@ -90,10 +90,19 @@ class EthTokenService(object):
         else:
             return result
 
-    def _bytes_to_string(self, b):
+    def _bytes_to_string(self, b, ignore_errors=True):
         if b is None:
             return b
-        b = b.decode('utf-8')
+
+        try:
+            b = b.decode('utf-8')
+        except UnicodeDecodeError as e:
+            if ignore_errors:
+                logger.debug('A UnicodeDecodeError exception occurred while trying to decode bytes to string', exc_info=True)
+                b = None
+            else:
+                raise e
+
         if self._function_call_result_transformer is not None:
             b = self._function_call_result_transformer(b)
         return b
@@ -105,8 +114,8 @@ def call_contract_function(func, ignore_errors, default_value=None):
         return result
     except Exception as ex:
         if type(ex) in ignore_errors:
-            logger.exception('An exception occurred in function {} of contract {}. '.format(func.fn_name, func.address)
-                             + 'This exception can be safely ignored.')
+            logger.debug('An exception occurred in function {} of contract {}. '.format(func.fn_name, func.address)
+                             + 'This exception can be safely ignored.', exc_info=True)
             return default_value
         else:
             raise ex
